@@ -30,24 +30,13 @@ class Sequence(KerasSequence):
             raise ValueError(
                 "Given sequence length must be a strictly positive integer."
             )
-        if not isinstance(batch_size, int) or batch_size == 0:
-            raise ValueError(
-                "Given batch size must be a strictly positive integer."
-            )
-        if samples_number < batch_size:
-            raise ValueError((
-                "Given sequence length ({}) "
-                "is smaller than a single batch of size ({})."
-            ).format(
-                samples_number,
-                batch_size
-            ))
+
         if not isinstance(elapsed_epochs, int) or elapsed_epochs < 0:
             raise ValueError(
                 "Given elapsed epochs must be a non-negative integer."
             )
         self._samples_number = samples_number
-        self._batch_size = batch_size
+        Sequence.batch_size.fset(self, batch_size) # pylint: disable=no-member
         self._elapsed_epochs = elapsed_epochs
 
     def on_epoch_end(self):
@@ -59,6 +48,23 @@ class Sequence(KerasSequence):
         """Return batch size property of the sequence."""
         return self._batch_size
 
+    @batch_size.setter
+    def batch_size(self, batch_size: int) -> int:
+        """Set batch size value."""
+        if not isinstance(batch_size, int) or batch_size == 0:
+            raise ValueError(
+                "Given batch size must be a strictly positive integer."
+            )
+        if self._samples_number < batch_size:
+            raise ValueError((
+                "Given sequence length ({}) "
+                "is smaller than a single batch of size ({})."
+            ).format(
+                self._samples_number,
+                batch_size
+            ))
+        self._batch_size = batch_size
+
     def reset(self):
         """Reset sequence to before training was started."""
         self._elapsed_epochs = 0
